package
Version:
v0.1.2
Opens a new window with list of versions in this module.
Published: Mar 2, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Check struct {
Name string `json:"name"`
Passed bool `json:"passed"`
Details string `json:"details"`
}
Check is one validation check result.
type Report struct {
OK bool `json:"ok"`
Checks []Check `json:"checks"`
}
Report is the complete validation result.
Run executes validation checks for read/analysis safety.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.